@@ -1,11 +1,8 @@
 import configparser
-import logging
 from pathlib import Path
 
 import appdirs
 
-logger = logging.getLogger(__name__)
-
 
 class Config:
     def __init__(self):
@@ -22,11 +19,9 @@ class Config:
         self.config["DEFAULT"]["dustforce_path"] = new_path
 
     def read(self):
-        logger.info(f"Reading config file: {self.path}")
         self.config.read(self.path)
 
     def write(self):
-        logger.info(f"Writing config file: {self.path}")
         self.path.parent.mkdir(parents=True, exist_ok=True)
         with self.path.open("w+") as file:
             self.config.write(file)
