@@ -1,3 +1,4 @@
+import logging
 import os
 import queue
 import re
@@ -20,6 +21,8 @@ LEVEL_PATTERN = r"START (.*)"
 COORD_PATTERN = r"(\d*) (-?\d*) (-?\d*)"
 CHARACTERS = ["dustman", "dustgirl", "dustkid", "dustworth"]
 
+log = logging.getLogger(__name__)
+
 
 class LoadReplayDialog(SimpleDialog):
     def __init__(self, app):
@@ -64,6 +67,9 @@ class App(tk.Tk):
     def __init__(self):
         super().__init__()
 
+        # Log exceptions
+        self.report_callback_exception = lambda *args: log.error("", exc_info=args)
+
         self.level = Level()
         self.character = 0
         self.inputs = Inputs()
